@@ -1,3 +1,4 @@
+use std::path::PathBuf;
 use std::sync::mpsc::{Receiver,Sender};
 use std::thread;
 use std::time::SystemTime;
@@ -5,12 +6,16 @@ use std::time::SystemTime;
 use notify::DebouncedEvent;
 
 pub struct ChangeEvent {
+    pub path: PathBuf,
     pub time: SystemTime
 }
 
 impl ChangeEvent {
-    pub fn new() -> Self {
-        Self { time: SystemTime::now() }
+    pub fn new(path: PathBuf) -> Self {
+        Self {
+            path: path,
+            time: SystemTime::now()
+        }
     }
 }
 
@@ -39,12 +44,20 @@ pub fn run(
 /// Convert to change event, return none if this one should
 /// be ignored.
 fn convert(event: DebouncedEvent) -> Option<ChangeEvent> {
-    match event {
-        DebouncedEvent::Create(_) |
-            DebouncedEvent::Write(_) |
-            DebouncedEvent::Chmod(_) |
-            DebouncedEvent::Remove(_) |
-            DebouncedEvent::Rename(_, _) => Some(ChangeEvent::new()),
-       _ => None
+    // Extract path
+    let path = match event {
+        DebouncedEvent::Create(p) => p,
+        DebouncedEvent::Write(p) => p,
+        DebouncedEvent::Chmod(p) => p,
+        DebouncedEvent::Remove(p) => p,
+        DebouncedEvent::Rename(_, p) => p,
+       _ => return None
+    };
+
+    // Only return it if the path exists
+    if path.exists() {
+        Some(ChangeEvent::new(path))
+    } else {
+        None
     }
 }
